@@ -5,6 +5,12 @@
 
 #include "rcpp_util.h"
 
+#include <Rcpp.h>
+
+#include <algorithm>
+#include <cctype>
+#include <string>
+
 // convert data frame to numeric matrix in Rcpp
 Rcpp::NumericMatrix df_to_matrix_(const Rcpp::DataFrame &df) {
     Rcpp::NumericMatrix m = Rcpp::no_init(df.nrows(), df.size());
@@ -133,9 +139,34 @@ bool contains_str_(const Rcpp::CharacterVector &v, const Rcpp::String &s) {
         return true;
 }
 
+// does std::string contain a space character
+bool has_space_char_(const std::string &s) {
+    for (char c : s) {
+        if (std::isspace(static_cast<unsigned char>(c)))
+            return true;
+    }
+    return false;
+}
+
 // wrapper for base R isNamespaceLoaded()
 bool is_namespace_loaded_(const Rcpp::String &pkg) {
     Rcpp::Function f("isNamespaceLoaded");
     Rcpp::LogicalVector res = f(pkg);
     return Rcpp::is_true(Rcpp::all(res));
 }
+
+// is this a gdalraster spatial object?
+bool is_gdalraster_obj_(const Rcpp::RObject &x) {
+    if (x.isNULL())
+        return false;
+
+    if (x.isObject()) {
+        const Rcpp::String cls = x.attr("class");
+        if (cls == "Rcpp_GDALRaster" || cls == "Rcpp_GDALVector")
+            return true;
+        else
+            return false;
+    }
+
+    return false;
+}
