@@ -332,6 +332,38 @@ std::string srs_to_projjson(const std::string &srs,
 //' axis.
 //' * `OAMS_CUSTOM`: custom-defined data axis
 //'
+//' `srs_get_area_of_use()` is a wrapper of `OSRGetAreaOfUse()` in the GDAL API.
+//' Returns a named list containing the following elements (or returns `NULL` if
+//' the API call does not succeed):
+//' * `AreaName`: the area of use
+//' * `WestLongitudeDeg`: the western-most longitude expressed in degree, or
+//' `NA` if the bounding box is unknown
+//' * `SouthLatitudeDeg`: the southern-most latitude expressed in degree, or
+//' `NA` if the bounding box is unknown
+//' * `EastLongitudeDeg`: the eastern-most longitude expressed in degree, or
+//' `NA` if the bounding box is unknown
+//' * `NorthLatitudeDeg`: the northern-most latitude expressed in degree, or
+//' `NA` if the bounding box is unknown
+//'
+//' `srs_get_axes_count()` returns the integer number of axes of the coordinate
+//' system of the SRS. Wrapper of `OSRGetAxesCount()` in the GDAL API.
+//'
+//' `srs_get_axes()` returns a named list of the axis names and their
+//' orientations. Wrapper of `OSRGetAxis()` in the GDAL API.
+//'
+//' `srs_epsg_treats_as_lat_long()` returns `TRUE` if this geographic coordinate
+//' system should be treated as having latitude/longitude coordinate ordering.
+//' Wrapper of `OSREPSGTreatsAsLatLong()` in the GDAL API.
+//'
+//' `srs_epsg_treats_as_northing_easting()` returns `TRUE` if this geographic
+//' coordinate system should be treated as having northing/easting coordinate
+//' ordering. Wrapper of `OSREPSGTreatsAsNorthingEasting()` in the GDAL API.
+//'
+//' `srs_get_celestial_body_name()` returns the name of the celestial body of
+//' the SRS, e.g., `"Earth"` for an Earth SRS. Wrapper of
+//' `OSRGetCelestialBodyName()` in the GDAL API. Requires GDAL >= 3.12 and
+//' PROJ >= 8.1.
+//'
 //' @param srs Character string containing an SRS definition in various
 //' formats (e.g., WKT, PROJ.4 string, well known name such as NAD27, NAD83,
 //' WGS84, etc., see [srs_to_wkt()]).
@@ -350,6 +382,8 @@ std::string srs_to_projjson(const std::string &srs,
 //' in a data frame, including a confidence value (0-100) for each match. The
 //' default is `FALSE` which returns a character string in the form
 //' `"EPSG:<code>"` for the first match (highest confidence).
+//' @param target_key Optional character string giving the coordinate system
+//' part to query, either `"PROJCS"` or `"GEOGCS"` (case-insensitive)
 //'
 //' @seealso
 //' [srs_convert]
@@ -398,6 +432,29 @@ std::string srs_to_projjson(const std::string &srs,
 //'
 //' srs_is_vertical("EPSG:5705")
 //'
+//' srs_get_area_of_use("EPSG:3976")
+//'
+//' srs_get_axes_count("EPSG:4326")
+//' srs_get_axes_count("EPSG:4979")
+//'
+//' # ordered list of axis names and their orientation
+//' srs_get_axes("EPSG:4326+5773")
+//'
+//' srs_epsg_treats_as_lat_long("WGS84")
+//'
+//' # NAD83 / Conus Albers:
+//' srs_epsg_treats_as_northing_easting("EPSG:5070")
+//' # WGS 84 / UPS North (N,E):
+//' srs_epsg_treats_as_northing_easting("EPSG:32661")
+//' # WGS 84 / UPS South (N,E):
+//' srs_epsg_treats_as_northing_easting("EPSG:32761")
+//'
+//' ## Requires GDAL >= 3.12 and PROJ >= 8.1
+//' # srs_get_celestial_body_name("EPSG:4326")
+//' #> [1] "Earth"
+//' # srs_get_celestial_body_name("IAU_2015:30100")
+//' #> [1] "Moon"
+//'
 //' f <- system.file("extdata/storml_elev.tif", package="gdalraster")
 //' ds <- new(GDALRaster, f)
 //'
@@ -412,7 +469,7 @@ std::string srs_to_projjson(const std::string &srs,
 //'
 //' ds$close()
 //'
-//' # Requires GDAL >= 3.4
+//' ## Requires GDAL >= 3.4
 //' if (gdal_version_num() >= gdal_compute_version(3, 4, 0)) {
 //'   if (srs_is_dynamic("WGS84"))
 //'     print("WGS84 is dynamic")
@@ -853,3 +910,383 @@ std::string srs_get_axis_mapping_strategy(const std::string &srs) {
     else
         return "";
 }
+
+//' @rdname srs_query
+// [[Rcpp::export]]
+SEXP srs_get_area_of_use(const std::string &srs) {
+    if (srs == "")
+        return R_NilValue;
+
+    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
+
+    if (OSRSetFromUserInput(hSRS, srs.c_str()) != OGRERR_NONE) {
+        if (hSRS != nullptr)
+            OSRDestroySpatialReference(hSRS);
+        Rcpp::stop("error importing SRS from user input");
+    }
+
+    double dfWestLongitudeDeg = NA_REAL;
+    double dfSouthLatitudeDeg = NA_REAL;
+    double dfEastLongitudeDeg = NA_REAL;
+    double dfNorthLatitudeDeg = NA_REAL;
+    const char *pszAreaName = nullptr;
+
+    if (!OSRGetAreaOfUse(hSRS, &dfWestLongitudeDeg, &dfSouthLatitudeDeg,
+                         &dfEastLongitudeDeg, &dfNorthLatitudeDeg,
+                         &pszAreaName)) {
+
+        OSRDestroySpatialReference(hSRS);
+        Rcpp::Rcout << "OSRGetAreaOfUse() API call did not succeed\n";
+        return R_NilValue;
+    }
+
+    Rcpp::List list_out = Rcpp::List::create();
+    if (pszAreaName)
+        list_out.push_back(pszAreaName, "AreaName");
+    else
+        list_out.push_back("", "AreaName");
+    if (dfWestLongitudeDeg != -1000)
+        list_out.push_back(dfWestLongitudeDeg, "WestLongitudeDeg");
+    else
+        list_out.push_back(NA_REAL, "WestLongitudeDeg");
+    if (dfSouthLatitudeDeg != -1000)
+        list_out.push_back(dfSouthLatitudeDeg, "SouthLatitudeDeg");
+    else
+        list_out.push_back(NA_REAL, "SouthLatitudeDeg");
+    if (dfEastLongitudeDeg != -1000)
+        list_out.push_back(dfEastLongitudeDeg, "EastLongitudeDeg");
+    else
+        list_out.push_back(NA_REAL, "EastLongitudeDeg");
+    if (dfNorthLatitudeDeg != -1000)
+        list_out.push_back(dfNorthLatitudeDeg, "NorthLatitudeDeg");
+    else
+        list_out.push_back(NA_REAL, "NorthLatitudeDeg");
+
+    OSRDestroySpatialReference(hSRS);
+    return list_out;
+}
+
+//' @rdname srs_query
+// [[Rcpp::export]]
+int srs_get_axes_count(const std::string &srs) {
+    if (srs == "")
+        return NA_INTEGER;
+
+    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
+
+    if (OSRSetFromUserInput(hSRS, srs.c_str()) != OGRERR_NONE) {
+        if (hSRS != nullptr)
+            OSRDestroySpatialReference(hSRS);
+        Rcpp::stop("error importing SRS from user input");
+    }
+
+    int axes_count = OSRGetAxesCount(hSRS);
+    OSRDestroySpatialReference(hSRS);
+    return axes_count;
+}
+
+//' @rdname srs_query
+// [[Rcpp::export]]
+SEXP srs_get_axes(const std::string &srs,
+    const Rcpp::Nullable<Rcpp::CharacterVector> &target_key = R_NilValue) {
+
+    if (srs == "")
+        return R_NilValue;
+
+    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
+
+    if (OSRSetFromUserInput(hSRS, srs.c_str()) != OGRERR_NONE) {
+        if (hSRS != nullptr)
+            OSRDestroySpatialReference(hSRS);
+        Rcpp::stop("error importing SRS from user input");
+    }
+
+    const char *pszTargetKey = nullptr;
+    if (target_key.isNotNull()) {
+        Rcpp::CharacterVector target_key_in(target_key);
+        if (target_key_in.size() > 0) {
+            if (!EQUAL(target_key_in[0], "GEOGCS") &&
+                !EQUAL(target_key_in[0], "PROJCS")) {
+
+                OSRDestroySpatialReference(hSRS);
+                Rcpp::stop(
+                    "'target_key' must be one of \"GEOGCS\" or \"PROJCS\"");
+            }
+            Rcpp::String s(target_key_in[0]);
+            pszTargetKey = s.get_cstring();
+        }
+    }
+
+    int axes_count = OSRGetAxesCount(hSRS);
+    if (axes_count <= 0) {
+        OSRDestroySpatialReference(hSRS);
+        return R_NilValue;
+    }
+
+    Rcpp::List axes_out = Rcpp::List::create();
+    bool is_axis_found = false;
+    for (int i = 0; i < axes_count; ++i) {
+        const char *axis_name = nullptr;
+        OGRAxisOrientation orientation = OAO_Other;
+        axis_name = OSRGetAxis(hSRS, pszTargetKey, i, &orientation);
+
+        if (!axis_name)
+            axis_name = std::to_string(i).c_str();
+        else
+            is_axis_found = true;
+
+        Rcpp::String axis_name_r(axis_name);
+        axis_name_r.replace_all(" ", "_");
+
+        if (orientation == OAO_Other)
+            axes_out.push_back("other", axis_name_r);
+        else if (orientation == OAO_North)
+            axes_out.push_back("north", axis_name_r);
+        else if (orientation == OAO_South)
+            axes_out.push_back("south", axis_name_r);
+        else if (orientation == OAO_East)
+            axes_out.push_back("east", axis_name_r);
+        else if (orientation == OAO_West)
+            axes_out.push_back("west", axis_name_r);
+        else if (orientation == OAO_Up)
+            axes_out.push_back("up", axis_name_r);
+        else if (orientation == OAO_Down)
+            axes_out.push_back("down", axis_name_r);
+        else
+            axes_out.push_back(NA_STRING, axis_name_r);
+    }
+
+    OSRDestroySpatialReference(hSRS);
+
+    if (is_axis_found)
+        return axes_out;
+    else
+        return R_NilValue;
+}
+
+//' @rdname srs_query
+// [[Rcpp::export]]
+bool srs_epsg_treats_as_lat_long(const std::string &srs) {
+    if (srs == "")
+        return false;
+
+    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
+
+    if (OSRSetFromUserInput(hSRS, srs.c_str()) != OGRERR_NONE) {
+        if (hSRS != nullptr)
+            OSRDestroySpatialReference(hSRS);
+        Rcpp::stop("error importing SRS from user input");
+    }
+
+    bool ret = OSREPSGTreatsAsLatLong(hSRS);
+    OSRDestroySpatialReference(hSRS);
+    return ret;
+}
+
+//' @rdname srs_query
+// [[Rcpp::export]]
+bool srs_epsg_treats_as_northing_easting(const std::string &srs) {
+    if (srs == "")
+        return false;
+
+    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
+
+    if (OSRSetFromUserInput(hSRS, srs.c_str()) != OGRERR_NONE) {
+        if (hSRS != nullptr)
+            OSRDestroySpatialReference(hSRS);
+        Rcpp::stop("error importing SRS from user input");
+    }
+
+    bool ret = OSREPSGTreatsAsNorthingEasting(hSRS);
+    OSRDestroySpatialReference(hSRS);
+    return ret;
+}
+
+//' @rdname srs_query
+// [[Rcpp::export]]
+std::string srs_get_celestial_body_name(const std::string &srs) {
+#if GDAL_VERSION_NUM < GDAL_COMPUTE_VERSION(3, 12, 0)
+    Rcpp::stop("srs_get_celestial_body_name() requires GDAL >= 3.12");
+#else
+    if (srs == "")
+        return "";
+
+    std::vector<int> proj_ver = getPROJVersion();
+    if (!(proj_ver[0] > 8 || (proj_ver[0] == 8 && proj_ver[1] >= 1)))
+        Rcpp::stop("srs_get_celestial_body_name() requires PROJ >= 8.1");
+
+    OGRSpatialReferenceH hSRS = OSRNewSpatialReference(nullptr);
+
+    if (OSRSetFromUserInput(hSRS, srs.c_str()) != OGRERR_NONE) {
+        if (hSRS != nullptr)
+            OSRDestroySpatialReference(hSRS);
+        Rcpp::stop("error importing SRS from user input");
+    }
+
+    const char *pszName = OSRGetCelestialBodyName(hSRS);
+    std::string ret = "";
+    if (pszName)
+        ret = pszName;
+
+    OSRDestroySpatialReference(hSRS);
+    return ret;
+#endif  // GDAL 3.12
+}
+
+//' Obtain information about coordinate reference systems in the PROJ DB
+//'
+//' `srs_info_from_db()` returns a data frame containing descriptive information
+//' about spatial coordinate reference systems in the PROJ database. Wrapper of
+//' `OSRGetCRSInfoListFromDatabase()` in the GDAL SRS API.
+//'
+//' @details
+//' The returned information includes the authority name, object code, object
+//' name, object type (e.g., Geographic 2D CRS, Geographic 3D CRS, Projected
+//' CRS, etc.), whether the object is deprecated, whether the bounding box
+//' values for the area of use are valid, the bounding box values in longitude
+//' and latitude degrees, the name of the area of use, the name of the
+//' projection method for a projected CRS, and the name of the celestial body of
+//' the CRS (e.g., "Earth", populated only if GDAL >= 3.12 and PROJ >= 8.1).
+//'
+//' @param auth_name Character string containing an authority name used to
+//' restrict the search, or empty string (`""`) for all authorities (the
+//' default).
+//' @returns
+//' A data frame (will contain `0` rows if no objects are found that match the
+//' search criterion).
+//'
+//' @seealso
+//' [srs_query]
+//'
+//' @examples
+//' epsg <- srs_info_from_db("EPSG")
+//' str(epsg)
+//'
+//' iau <- srs_info_from_db("IAU_2015")
+//' str(iau)
+// [[Rcpp::export]]
+Rcpp::DataFrame srs_info_from_db(std::string auth_name = "") {
+    const char *pszAuthName = nullptr;
+    if (auth_name != "")
+        pszAuthName = auth_name.c_str();
+
+    int nObjects = 0;
+    std::unique_ptr<OSRCRSInfo *, decltype(&OSRDestroyCRSInfoList)>
+        pCRSList(OSRGetCRSInfoListFromDatabase(pszAuthName, nullptr, &nObjects),
+                 OSRDestroyCRSInfoList);
+
+    Rcpp::CharacterVector auth_name_vec(nObjects, NA_STRING);
+    Rcpp::CharacterVector obj_code_vec(nObjects, NA_STRING);
+    Rcpp::CharacterVector obj_name_vec(nObjects, NA_STRING);
+    Rcpp::CharacterVector obj_type_vec(nObjects, NA_STRING);
+    Rcpp::LogicalVector is_deprecated_vec(nObjects, NA_LOGICAL);
+    Rcpp::LogicalVector is_bbox_valid_vec(nObjects, NA_LOGICAL);
+    Rcpp::NumericVector west_longitude_vec(nObjects, NA_REAL);
+    Rcpp::NumericVector south_latitude_vec(nObjects, NA_REAL);
+    Rcpp::NumericVector east_longitude_vec(nObjects, NA_REAL);
+    Rcpp::NumericVector north_latitude_vec(nObjects, NA_REAL);
+    Rcpp::CharacterVector area_name_vec(nObjects, NA_STRING);
+    Rcpp::CharacterVector proj_method_vec(nObjects, NA_STRING);
+    Rcpp::CharacterVector celestial_body_name_vec(nObjects, NA_STRING);
+
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3, 12, 0)
+    bool is_proj_8_1_min = false;
+    std::vector<int> proj_ver = getPROJVersion();
+    if (proj_ver[0] > 8 || (proj_ver[0] == 8 && proj_ver[1] >= 1))
+        is_proj_8_1_min = true;
+#endif  // GDAL >= 3.12
+
+    for (int i = 0; i < nObjects; ++i) {
+        const auto *entry = (pCRSList.get())[i];
+        if (entry->pszAuthName)
+            auth_name_vec[i] = entry->pszAuthName;
+        if (entry->pszCode)
+            obj_code_vec[i] = entry->pszCode;
+        if (entry->pszName)
+            obj_name_vec[i] = entry->pszName;
+
+        switch (entry->eType) {
+            case OSR_CRS_TYPE_GEOGRAPHIC_2D:
+                obj_type_vec[i] = "Geographic 2D";
+            break;
+            case OSR_CRS_TYPE_GEOGRAPHIC_3D:
+                obj_type_vec[i] = "Geographic 3D";
+            break;
+            case OSR_CRS_TYPE_GEOCENTRIC:
+                obj_type_vec[i] = "Geocentric";
+            break;
+            case OSR_CRS_TYPE_PROJECTED:
+                obj_type_vec[i] = "Projected";
+            break;
+            case OSR_CRS_TYPE_VERTICAL:
+                obj_type_vec[i] = "Vertical";
+            break;
+            case OSR_CRS_TYPE_COMPOUND:
+                obj_type_vec[i] = "Compound";
+            break;
+            case OSR_CRS_TYPE_OTHER:
+                obj_type_vec[i] = "Other";
+            break;
+            default:
+                obj_type_vec[i] = "unhandled CRS type";
+            break;
+        }
+
+        if (entry->bDeprecated)
+            is_deprecated_vec[i] = TRUE;
+        else
+            is_deprecated_vec[i] = FALSE;
+
+        if (entry->bBboxValid)
+            is_bbox_valid_vec[i] = TRUE;
+        else
+            is_bbox_valid_vec[i] = FALSE;
+
+        if (entry->dfWestLongitudeDeg != -1000)
+            west_longitude_vec[i] = entry->dfWestLongitudeDeg;
+        if (entry->dfSouthLatitudeDeg != -1000)
+            south_latitude_vec[i] = entry->dfSouthLatitudeDeg;
+        if (entry->dfEastLongitudeDeg != -1000)
+            east_longitude_vec[i] = entry->dfEastLongitudeDeg;
+        if (entry->dfNorthLatitudeDeg != -1000)
+            north_latitude_vec[i] = entry->dfNorthLatitudeDeg;
+
+        if (entry->pszAreaName)
+            area_name_vec[i] = entry->pszAreaName;
+        if (entry->pszProjectionMethod)
+            proj_method_vec[i] = entry->pszProjectionMethod;
+
+#if GDAL_VERSION_NUM >= GDAL_COMPUTE_VERSION(3, 12, 0)
+        if (is_proj_8_1_min) {
+            if (entry->pszCelestialBodyName)
+                celestial_body_name_vec[i] = entry->pszCelestialBodyName;
+        }
+#endif  // GDAL >= 3.12
+    }
+
+    Rcpp::List df(13);
+    Rcpp::CharacterVector col_names =
+        {"auth_name", "obj_code", "obj_name", "obj_type", "is_deprecated",
+         "is_bbox_valid", "west_long_deg", "south_lat_deg", "east_long_deg",
+         "north_lat_deg", "area_of_use", "projection_method",
+         "celestial_body_name"};
+
+    df[0] = auth_name_vec;
+    df[1] = obj_code_vec;
+    df[2] = obj_name_vec;
+    df[3] = obj_type_vec;
+    df[4] = is_deprecated_vec;
+    df[5] = is_bbox_valid_vec;
+    df[6] = west_longitude_vec;
+    df[7] = south_latitude_vec;
+    df[8] = east_longitude_vec;
+    df[9] = north_latitude_vec;
+    df[10] = area_name_vec;
+    df[11] = proj_method_vec;
+    df[12] = celestial_body_name_vec;
+
+    df.attr("class") = Rcpp::CharacterVector{"data.frame"};
+    df.names() = col_names;
+    df.attr("row.names") = Rcpp::seq_len(nObjects);
+    return df;
+}
