@@ -35,5 +35,14 @@ SEXP srs_get_linear_units(const std::string &srs);
 double srs_get_coord_epoch(const std::string &srs);
 int srs_get_utm_zone(const std::string &srs);
 std::string srs_get_axis_mapping_strategy(const std::string &srs);
+SEXP srs_get_area_of_use(const std::string &srs);
+int srs_get_axes_count(const std::string &srs);
+SEXP srs_get_axes(const std::string &srs,
+                  const Rcpp::Nullable<Rcpp::CharacterVector> &target_key);
+bool srs_epsg_treats_as_lat_long(const std::string &srs);
+bool srs_epsg_treats_as_northing_easting(const std::string &srs);
+std::string srs_get_celestial_body_name(const std::string &srs);
+
+Rcpp::DataFrame srs_info_from_db(std::string auth_name);
 
 #endif  // SRS_API_H_
